@@ -46,8 +46,7 @@ class GSPeerConnectionBroadcaster:
             if self.gsdbs.credentials["turnenable"]:
                 self.rtconfiList.append(RTCIceServer(urls=self.gsdbs.credentials["turnserver"],
                                                      username=self.gsdbs.credentials["turnuser"],
-                                                     credential=self.gsdbs.credentials["turnpw"],
-                                                     credentialType="pw"
+                                                     credential=self.gsdbs.credentials["turnpw"]
                                                      ))
 
             camera.resolution = (self.gsdbs.credentials["hres"], self.gsdbs.credentials["vres"])
@@ -87,6 +86,7 @@ class GSPeerConnectionBroadcaster:
 
             @self.sio.event
             async def watcher(id):
+                self._logger.info(str(self.rtconfiList))
                 if len(self.rtconfiList) > 0:
                     pc = RTCPeerConnection(configuration=RTCConfiguration(
                         self.rtconfiList
